@@ -26,6 +26,7 @@
 #include "../fbreader/FBReader.h"
 #include "../options/FBOptions.h"
 #include "../options/FBTextStyle.h"
+#include "../library/Library.h"
 
 const ZLTypeId FBReaderNode::TYPE_ID(ZLBlockTreeNode::TYPE_ID);
 
@@ -118,7 +119,12 @@ void FBReaderNode::drawTitle(ZLPaintContext &context, int vOffset) {
 		FBOptions::Instance().RegularTextColorOption.value());
 	context.setFont(style.fontFamily(), style.fontSize(), style.bold(), style.italic());
 
-	const std::string text = title();
+	std::string text;
+	if ((Library::Instance().BasicLibraryViewOption.value()) && !children().empty()) {
+		text = (isOpen()? "- " : "+ ") + title();
+	} else {
+		text = title();
+	}
 	const int stringW = context.stringWidth(text.data(), text.size(), false);
 	const int stringH = context.stringHeight();
 	context.drawString(hOffset, vOffset + 2 * unit, text.data(), text.size(), false);
@@ -226,9 +232,13 @@ int FBReaderNode::height(ZLPaintContext &context) const {
 			break;
 		}
 	}
-	return
-		unitSize(context, FBTextStyle::Instance()) *
-			(hasAuxHyperlink ? 13 : 11) / 2;
+	if (Library::Instance().BasicLibraryViewOption.value()) {
+		return unitSize(context, FBTextStyle::Instance()) * 3;
+	} else {
+		return
+			unitSize(context, FBTextStyle::Instance()) *
+				(hasAuxHyperlink ? 13 : 11) / 2;
+	}
 }
 
 int FBReaderNode::unitSize(ZLPaintContext &context, const FBTextStyle &style) const {
@@ -261,18 +271,21 @@ void FBReaderNode::paint(ZLPaintContext &context, int vOffset) {
 
 	removeAllHyperlinks();
 
-	drawCover(context, vOffset);
 	drawTitle(context, vOffset);
-	drawSummary(context, vOffset);
 
-	int left = 0;
-	int auxLeft = 0;
-	for (std::vector<std::pair<shared_ptr<ZLRunnableWithKey>,bool> >::const_iterator it = myActions.begin(); it != myActions.end(); ++it) {
-		if (it->first->makesSense()) {
-			if (it->second) {
-				drawHyperlink(context, auxLeft, vOffset, it->first, true);
-			} else {
-				drawHyperlink(context, left, vOffset, it->first);
+	if (! Library::Instance().BasicLibraryViewOption.value()) {
+		drawCover(context, vOffset);
+		drawSummary(context, vOffset);
+
+		int left = 0;
+		int auxLeft = 0;
+		for (std::vector<std::pair<shared_ptr<ZLRunnableWithKey>,bool> >::const_iterator it = myActions.begin(); it != myActions.end(); ++it) {
+			if (it->first->makesSense()) {
+				if (it->second) {
+					drawHyperlink(context, auxLeft, vOffset, it->first, true);
+				} else {
+					drawHyperlink(context, left, vOffset, it->first);
+				}
 			}
 		}
 	}
