@@ -83,6 +83,7 @@ FBReader::FBReader(const std::string &bookToOpen) :
 	ZLApplication("FBReader"),
 	QuitOnCancelOption(ZLCategoryKey::CONFIG, OPTIONS, "QuitOnCancel", false),
 	AlwaysStartInLibraryOption(ZLCategoryKey::CONFIG, OPTIONS, "AlwaysStartInLibrary", false),
+	StartFullscreenOption(ZLCategoryKey::CONFIG, OPTIONS, "StartFullscreen", false),
 	KeyScrollingDelayOption(ZLCategoryKey::CONFIG, "Scrollings", "Delay", 0, 2000, 100),
 	LinesToScrollOption(ZLCategoryKey::CONFIG, "SmallScrolling", "LinesToScroll", 1, 20, 1),
 	LinesToKeepOption(ZLCategoryKey::CONFIG, "LargeScrolling", "LinesToKeepOption", 0, 20, 0),
@@ -107,6 +108,7 @@ FBReader::FBReader(const std::string &bookToOpen) :
 	myNetworkLibraryView = new NetworkView(*context());
 	myLibraryByAuthorView = new LibraryByAuthorView(*context());
 	myLibraryByTagView = new LibraryByTagView(*context());
+	myLibraryByBookView = new LibraryByBookView(*context());
 	myRecentBooksPopupData = new RecentBooksPopupData();
 	myMode = UNDEFINED_MODE;
 	myPreviousMode = BOOK_TEXT_MODE;
@@ -159,6 +161,7 @@ FBReader::FBReader(const std::string &bookToOpen) :
 	shared_ptr<Action> booksOrderAction = new BooksOrderAction();
 	addAction(ActionCode::ORGANIZE_BOOKS_BY_AUTHOR, booksOrderAction);
 	addAction(ActionCode::ORGANIZE_BOOKS_BY_TAG, booksOrderAction);
+	addAction(ActionCode::ORGANIZE_BOOKS_BY_NAME, booksOrderAction);
 	addAction(ActionCode::FILTER_LIBRARY, new FilterLibraryAction());
 
 	myOpenFileHandler = new OpenFileHandler();
@@ -186,7 +189,11 @@ void FBReader::initWindow() {
 			createBook(myBookToOpen, book);
 		}
 		if ((book.isNull()) && AlwaysStartInLibraryOption.value()) {
-			book = BooksDBUtil::getBook(helpFileName("en"));
+			book = BooksDBUtil::getBook(helpFileName(ZLibrary::Language()));
+
+			if (book.isNull()) {
+				book = BooksDBUtil::getBook(helpFileName("en"));
+			}
 		}
 		if (book.isNull()) {
 			const BookList &books = Library::Instance().recentBooks();
@@ -214,6 +221,9 @@ void FBReader::initWindow() {
 	if (AlwaysStartInLibraryOption.value()) {
 		setMode(LIBRARY_MODE);
 	}
+    if (StartFullscreenOption.value()) {
+        doAction(ActionCode::FULLSCREEN_ON);
+    }
 }
 
 void FBReader::refreshWindow() {
@@ -383,8 +393,10 @@ bool FBReader::isViewFinal() const {
 void FBReader::showLibraryView() {
 	if (ZLStringOption(ZLCategoryKey::LOOK_AND_FEEL, "ToggleButtonGroup", "booksOrder", "").value() == ActionCode::ORGANIZE_BOOKS_BY_TAG) {
 		setView(myLibraryByTagView);
-	} else {
+	} else if (ZLStringOption(ZLCategoryKey::LOOK_AND_FEEL, "ToggleButtonGroup", "booksOrder", "").value() == ActionCode::ORGANIZE_BOOKS_BY_AUTHOR) {
 		setView(myLibraryByAuthorView);
+	} else {
+		setView(myLibraryByBookView);
 	}
 }
 
@@ -402,6 +414,7 @@ void FBReader::setMode(ViewMode mode) {
 
 	switch (myMode) {
 		case BOOK_TEXT_MODE:
+			checkFullscreenSetup(true);
 			setHyperlinkCursor(false);
 			((ZLTextView&)*myBookTextView).forceScrollbarUpdate();
 			setView(myBookTextView);
@@ -415,9 +428,11 @@ void FBReader::setMode(ViewMode mode) {
 			break;
 		case LIBRARY_MODE:
 		{
+			checkFullscreenSetup(false);
 			shared_ptr<Book> currentBook = myModel->book();
 			((LibraryView&)*myLibraryByAuthorView).showBook(currentBook);
 			((LibraryView&)*myLibraryByTagView).showBook(currentBook);
+			((LibraryView&)*myLibraryByBookView).showBook(currentBook);
 			showLibraryView();
 			break;
 		}
