@@ -37,6 +37,7 @@ FBIndicatorStyle::FBIndicatorStyle() :
 	IsSensitiveOption(ZLCategoryKey::LOOK_AND_FEEL, INDICATOR, "TouchSensitive", true),
 	ShowTextPositionOption(ZLCategoryKey::LOOK_AND_FEEL, INDICATOR, "PositionText", false),
 	ShowTimeOption(ZLCategoryKey::LOOK_AND_FEEL, INDICATOR, "Time", false),
+	ShowFSToggleOption(ZLCategoryKey::LOOK_AND_FEEL, INDICATOR, "FullScreen", false),
 	ColorOption(ZLCategoryKey::LOOK_AND_FEEL, INDICATOR, "Color", ZLColor(127, 127, 127)),
 	HeightOption(ZLCategoryKey::LOOK_AND_FEEL, INDICATOR, "Height", 1, 100, 16),
 	OffsetOption(ZLCategoryKey::LOOK_AND_FEEL, INDICATOR, "Offset", 0, 100, 3),
@@ -59,6 +60,10 @@ bool FBIndicatorStyle::isTimeShown() const {
 	return ShowTimeOption.value();
 }
 
+bool FBIndicatorStyle::isFSToggleShown() const {
+	return ShowFSToggleOption.value();
+}
+
 ZLColor FBIndicatorStyle::color() const {
 	return ColorOption.value();
 }
@@ -103,6 +108,14 @@ void FBView::doTapScrolling(int y) {
 	}
 }
 
+void FBView::doLineScrolling(bool forward) {
+	if (forward) {
+		FBReader::Instance().doAction(ActionCode::LINE_SCROLL_FORWARD);
+	} else {
+		FBReader::Instance().doAction(ActionCode::LINE_SCROLL_BACKWARD);
+	}
+}
+
 bool FBView::onFingerTap(int, int y) {
 	doTapScrolling(y);
 	return true;
@@ -185,8 +198,11 @@ bool FBView::onStylusRelease(int x, int y) {
 	FBReader &fbreader = FBReader::Instance();
 	myIsReleasedWithoutMotion =
 		myIsReleasedWithoutMotion && (abs(x - pressedX()) <= 5) && (abs(y - pressedY()) <= 5);
+
+	// Do scrolling by tapping
 	if (!hadSelection && isReleasedWithoutMotion() &&
 			fbreader.EnableTapScrollingOption.value() &&
+			!fbreader.TapScrollingOnDragOnlyOption.value() &&
 			(!ZLBooleanOption(ZLCategoryKey::EMPTY, ZLOption::PLATFORM_GROUP, ZLOption::FINGER_TAP_DETECTABLE, false).value() ||
 			 !fbreader.TapScrollingOnFingerOnlyOption.value())) {
 		myTapScroller = new TapScroller(*this, y);
@@ -194,6 +210,18 @@ bool FBView::onStylusRelease(int x, int y) {
 		return true;
 	}
 
+	// Do scrolling by dragging
+	int dx = x!=pressedX()? abs(x - pressedX()) : 1;
+	int dy = abs(y - pressedY());
+	if((dy / dx >= 5) && fbreader.TapScrollingOnDragOnlyOption.value()) {
+		if (fbreader.VariableDragOption.value() && (dy < fbreader.VariableDragLengthOption.value())) {
+		    doLineScrolling(y<pressedY());
+		} else {
+		    doTapScrolling(y>pressedY()? 0:context().height());
+		}
+		return true;
+	}
+
 	return false;
 }
 
