@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
 #include <ZLStringUtil.h>
 
 #include "OptionsDialog.h"
-#include "../options/FBOptions.h"
+#include "../options/FBCategoryKey.h"
 
 #include "../external/ProgramCollection.h"
 
